/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.4 Funktionen Fuzzy
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.fuzzylib;

import de.bsvrz.iav.fuzzylib.fuzzylib.FuzzySet;
import de.bsvrz.iav.fuzzylib.fuzzylib.LinguistischeVariable;

/**
 * Kapselt die Fuzzy-Sets und linguistische Variable sowie deren Testbelegung.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
@SuppressWarnings("nls")
public class KB implements TestDatumLV {

	/** Attributgruppe mit der linguistischen Variable. */
	public static final String ATG_FUZZY_SETS = "atg.bemessungsDichteFuzzy";

	/** Attributgruppe mit dem Fuzzy-Wert. */
	public static final String ATG_FUZZY_WERT = "atg.bemessungsDichte";

	/**
	 * Fuzzy-Set, was w&auml;hrend der mehrerer Test verwendet wird. Es wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 */
	public FuzzySet fsNiedrig;

	/**
	 * Fuzzy-Set, was w&auml;hrend der mehrerer Test verwendet wird. Es wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 */
	public FuzzySet fsNichtSehrHoch;

	/**
	 * Fuzzy-Set, was w&auml;hrend der mehrerer Test verwendet wird. Es wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 */
	public FuzzySet fsHoch;

	/**
	 * Fuzzy-Set, was w&auml;hrend der mehrerer Test verwendet wird. Es wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 */
	public FuzzySet fsSehrHoch;

	/**
	 * Linguistische Variable, die in mehreren Test verwendet wird. Sie wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 */
	public LinguistischeVariable lv;

	/**
	 * Testbelegung der Membervariablen erzeugen.
	 */
	public KB() {
		this(1);
	}

	/**
	 * Testbelegung der Membervariablen erzeugen.
	 *
	 * @param szenario
	 *            Szenario 1 bis 6
	 */
	public KB(final int szenario) {
		switch (szenario) {
		case 1:
		case 5:
			fsNiedrig = new FuzzySet("Niedrig", 0, 0, 25, 35);
			fsNichtSehrHoch = new FuzzySet("Nicht sehr hoch", 0, 0, 50, 70);
			fsHoch = new FuzzySet("Hoch", 25, 35, 50, 70);
			fsSehrHoch = new FuzzySet("Sehr hoch", 50, 70, 10000, 10000);
			break;
		case 2:
		case 6:
			fsNiedrig = new FuzzySet("Niedrig", 0, 0, 35, 45);
			fsNichtSehrHoch = new FuzzySet("Nicht sehr hoch", 0, 0, 60, 80);
			fsHoch = new FuzzySet("Hoch", 35, 45, 60, 80);
			fsSehrHoch = new FuzzySet("Sehr hoch", 60, 80, 10000, 10000);
			break;
		case 3:
			fsNiedrig = new FuzzySet("Niedrig", 0, 0, 35, 45);
			fsNichtSehrHoch = new FuzzySet("Nicht sehr hoch", 0, 0, 45, 55);
			fsHoch = new FuzzySet("Hoch", 35, 45, 45, 55);
			fsSehrHoch = new FuzzySet("Sehr hoch", 45, 55, 10000, 10000);
			break;
		case 4:
			fsNiedrig = new FuzzySet("Niedrig", 0, 0, 15, 25);
			fsNichtSehrHoch = new FuzzySet("Nicht sehr hoch", 0, 0, 40, 60);
			fsHoch = new FuzzySet("Hoch", 15, 25, 40, 60);
			fsSehrHoch = new FuzzySet("Sehr hoch", 40, 60, 10000, 10000);
			break;
		default:
			throw new IllegalArgumentException();
		}

		lv = new LinguistischeVariable("KB", 0, 10000);
		lv.addFuzzySet(fsNiedrig);
		lv.addFuzzySet(fsNichtSehrHoch);
		lv.addFuzzySet(fsHoch);
		lv.addFuzzySet(fsSehrHoch);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getAtgFuzzySets() {
		return ATG_FUZZY_SETS;
	}

	/**
	 * {@inheritDoc}
	 */

	@Override
	public String getAtgFuzzyWert() {
		return ATG_FUZZY_WERT;
	}

	/**
	 * {@inheritDoc}
	 */

	@Override
	public LinguistischeVariable getLinguistischeVariable() {
		return new KB(1).lv;
	}

	/**
	 * {@inheritDoc}
	 */

	@Override
	public LinguistischeVariable getLinguistischeVariable(final int szenario) {
		return new KB(szenario).lv;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getName() {
		return getClass().getSimpleName();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getSystemObjektTyp() {
		return "typ.messQuerschnittAllgemein";
	}

}
