/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.4 Funktionen Fuzzy
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.fuzzylib;

import de.bsvrz.iav.fuzzylib.fuzzylib.LinguistischeVariable;

/**
 * Fasst alle Testdaten die linguistische Variablen darstellen zusammen.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
@SuppressWarnings("nls")
public enum TestDatenLV implements TestDatumLV {

	/** Lkw-Anteil in Prozent. */
	ALkw("de.bsvrz.iav.fuzzylib.ALkw"),

	/** Helligkeit in Lux. */
	Helligkeit("de.bsvrz.iav.fuzzylib.Helligkeit"),

	/** Bemessungsdichte in Fahrzeuge/km. */
	KB("de.bsvrz.iav.fuzzylib.KB"),

	/** Niederschlagsintensit&auml;t in mm/h. */
	Ni("de.bsvrz.iav.fuzzylib.Ni"),

	/** Verkehrsst&auml;rke in Anzahl pro Messabschnittsdauer. */
	QKfz("de.bsvrz.iav.fuzzylib.QKfz"),

	/** Standardabweichung der Kfz-Geschwindigkeiten. */
	SKfz("de.bsvrz.iav.fuzzylib.SKfz"),

	/** Sichtweite in m. */
	SW("de.bsvrz.iav.fuzzylib.SW"),

	/** Geschwindigkeit in km/h. */
	VKfz("de.bsvrz.iav.fuzzylib.VKfz"),

	/** Windgeschwindigkeit inm/s. */
	WG("de.bsvrz.iav.fuzzylib.WG"),

	/** Windrichting in Grad. */
	WR("de.bsvrz.iav.fuzzylib.WR");

	/** Testdatum dieses {@code enum}. */
	private final TestDatumLV datum;

	/**
	 * Privater Konstruktor zum initialisieren des Testdatums.
	 *
	 * @param klasse
	 *            Voll qualifizierter Name einer Klasse vom Typ
	 *            {@code TestDatumLV}
	 */
	private TestDatenLV(final String klasse) {
		try {
			final Class<?> c = Class.forName(klasse);
			datum = (TestDatumLV) c.newInstance();
		} catch (final ClassNotFoundException e) {
			e.printStackTrace();
			throw new IllegalStateException();
		} catch (final InstantiationException e) {
			e.printStackTrace();
			throw new IllegalStateException();
		} catch (final IllegalAccessException e) {
			e.printStackTrace();
			throw new IllegalStateException();
		}
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getAtgFuzzySets() {
		return datum.getAtgFuzzySets();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getAtgFuzzyWert() {
		return datum.getAtgFuzzyWert();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public LinguistischeVariable getLinguistischeVariable() {
		return datum.getLinguistischeVariable();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public LinguistischeVariable getLinguistischeVariable(final int szenario) {
		return datum.getLinguistischeVariable(szenario);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getName() {
		return datum.getName();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getSystemObjektTyp() {
		return datum.getSystemObjektTyp();
	}

}
