/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.4 Funktionen Fuzzy
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.fuzzylib;

import de.bsvrz.iav.fuzzylib.fuzzylib.LinguistischeVariable;

/**
 * Diese Schnittstelle vereinheitlicht den Zugriff auf Testdaten, die
 * linguistische Variablen darstellen.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
public interface TestDatumLV {

	/**
	 * Gibt die PID der Attributgruppe mit den Fuzzy-Sets zur&uuml;ck.
	 *
	 * @return Eine PID
	 */
	String getAtgFuzzySets();

	/**
	 * Gibt die PID der Attributgruppe mit dem Fuzzy-Wert zur&uuml;ck.
	 *
	 * @return Eine PID
	 */
	String getAtgFuzzyWert();

	/**
	 * Gibt eine linguistische Variable als Testdatum zur&uuml;ck.
	 *
	 * @return Eine linguistische Variable
	 */
	LinguistischeVariable getLinguistischeVariable();

	/**
	 * Gibt eine bestimme linguistische Variable zur&uuml;ck.
	 *
	 * @param szenario
	 *            Nummer eines Szenarios, siehe [Afo]
	 * @return Eine linguistische Variable
	 */
	LinguistischeVariable getLinguistischeVariable(int szenario);

	/**
	 * Gibt den Namen des Testdatums zur&uuml;ck.
	 *
	 * @return Ein Name
	 */
	String getName();

	/**
	 * Gibt die PID des Objekttyps zur&uuml;ck.
	 *
	 * @return Eine PID
	 */
	String getSystemObjektTyp();

}
