/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.4 Funktionen Fuzzy
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.fuzzylib;

import de.bsvrz.iav.fuzzylib.fuzzylib.FuzzySet;
import de.bsvrz.iav.fuzzylib.fuzzylib.LinguistischeVariable;

/**
 * Kapselt die Fuzzy-Sets und linguistische Variable sowie deren Testbelegung.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
@SuppressWarnings("nls")
public class VKfz implements TestDatumLV {

	/** Attributgruppe mit der linguistischen Variable. */
	public static final String ATG_FUZZY_SETS = "atg.verkehrGeschwindigkeitFuzzy";

	/** Attributgruppe mit dem Fuzzy-Wert. */
	public static final String ATG_FUZZY_WERT = "atg.verkehrGeschwindigkeit";

	/**
	 * Fuzzy-Set, was w&auml;hrend der mehrerer Test verwendet wird. Es wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 */
	public FuzzySet fsNiedrig;

	/**
	 * Fuzzy-Set, was w&auml;hrend der mehrerer Test verwendet wird. Es wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 */
	public FuzzySet fsMittel;

	/**
	 * Fuzzy-Set, was w&auml;hrend der mehrerer Test verwendet wird. Es wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 */
	public FuzzySet fsHoch;

	/**
	 * Linguistische Variable, die in mehreren Test verwendet wird. Sie wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 */
	public LinguistischeVariable lv;

	/**
	 * Testbelegung der Membervariablen erzeugen.
	 */
	public VKfz() {
		this(1);
	}

	/**
	 * Testbelegung der Membervariablen erzeugen.
	 *
	 * @param szenario
	 *            Szenario 1 bis 6
	 */
	public VKfz(final int szenario) {
		switch (szenario) {
		case 1:
			fsNiedrig = new FuzzySet("Niedrig", 0, 0, 25, 35);
			fsMittel = new FuzzySet("Mittel", 25, 35, 75, 85);
			fsHoch = new FuzzySet("Hoch", 75, 85, 254, 254);
			break;
		case 2:
			fsNiedrig = new FuzzySet("Niedrig", 0, 0, 27, 36);
			fsMittel = new FuzzySet("Mittel", 27, 36, 77, 86);
			fsHoch = new FuzzySet("Hoch", 77, 86, 254, 254);
			break;
		case 3:
			fsNiedrig = new FuzzySet("Niedrig", 0, 0, 28, 36);
			fsMittel = new FuzzySet("Mittel", 28, 36, 78, 86);
			fsHoch = new FuzzySet("Hoch", 78, 86, 254, 254);
			break;
		case 4:
			fsNiedrig = new FuzzySet("Niedrig", 0, 0, 15, 30);
			fsMittel = new FuzzySet("Mittel", 15, 30, 60, 80);
			fsHoch = new FuzzySet("Hoch", 60, 80, 254, 254);
			break;
		case 5:
			fsNiedrig = new FuzzySet("Niedrig", 0, 0, 20, 30);
			fsMittel = new FuzzySet("Mittel", 20, 30, 70, 80);
			fsHoch = new FuzzySet("Hoch", 70, 80, 254, 254);
			break;
		case 6:
			fsNiedrig = new FuzzySet("Niedrig", 0, 0, 23, 33);
			fsMittel = new FuzzySet("Mittel", 23, 33, 73, 83);
			fsHoch = new FuzzySet("Hoch", 73, 83, 254, 254);
			break;
		default:
			throw new IllegalArgumentException();
		}

		lv = new LinguistischeVariable("VKfz", 0, 254);
		lv.addFuzzySet(fsNiedrig);
		lv.addFuzzySet(fsMittel);
		lv.addFuzzySet(fsHoch);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getAtgFuzzySets() {
		return ATG_FUZZY_SETS;
	}

	/**
	 * {@inheritDoc}
	 */

	@Override
	public String getAtgFuzzyWert() {
		return ATG_FUZZY_WERT;
	}

	/**
	 * {@inheritDoc}
	 */

	@Override
	public LinguistischeVariable getLinguistischeVariable() {
		return new VKfz(1).lv;
	}

	/**
	 * {@inheritDoc}
	 */

	@Override
	public LinguistischeVariable getLinguistischeVariable(final int szenario) {
		return new VKfz(szenario).lv;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getName() {
		return getClass().getSimpleName();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getSystemObjektTyp() {
		return "typ.messQuerschnittAllgemein";
	}

}
