/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.4 Funktionen Fuzzy
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.fuzzylib;

import de.bsvrz.iav.fuzzylib.fuzzylib.FuzzySet;
import de.bsvrz.iav.fuzzylib.fuzzylib.LinguistischeVariable;

/**
 * Kapselt die Fuzzy-Sets und linguistische Variable sowie deren Testbelegung.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
@SuppressWarnings("nls")
public class WR implements TestDatumLV {

	/** Attributgruppe mit der linguistischen Variable. */
	public static final String ATG_FUZZY_SETS = "atg.ufdsParameterWindRichtungFuzzy";

	/** Attributgruppe mit dem Fuzzy-Wert. */
	public static final String ATG_FUZZY_WERT = "atg.ufdsWindRichtungFuzzy";

	/**
	 * Fuzzy-Set, was w&auml;hrend der mehrerer Test verwendet wird. Es wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 */
	public FuzzySet fsNorden;

	/**
	 * Fuzzy-Set, was w&auml;hrend der mehrerer Test verwendet wird. Es wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 */
	public FuzzySet fsNordost;

	/**
	 * Fuzzy-Set, was w&auml;hrend der mehrerer Test verwendet wird. Es wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 */
	public FuzzySet fsOsten;

	/**
	 * Fuzzy-Set, was w&auml;hrend der mehrerer Test verwendet wird. Es wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 */
	public FuzzySet fsSuedost;

	/**
	 * Fuzzy-Set, was w&auml;hrend der mehrerer Test verwendet wird. Es wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 */
	public FuzzySet fsSueden;

	/**
	 * Fuzzy-Set, was w&auml;hrend der mehrerer Test verwendet wird. Es wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 */
	public FuzzySet fsSuedwest;

	/**
	 * Fuzzy-Set, was w&auml;hrend der mehrerer Test verwendet wird. Es wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 */
	public FuzzySet fsWesten;

	/**
	 * Fuzzy-Set, was w&auml;hrend der mehrerer Test verwendet wird. Es wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 */
	public FuzzySet fsNordwest;

	/**
	 * Linguistische Variable, die in mehreren Test verwendet wird. Sie wird vor
	 * jedem Test mit identischen Werten initialisiert.
	 * <p>
	 * Windrichtung als linguistische Variable, Beispiel f&uuml;r den
	 * Sonderfall, dass ein Fuzzy-Set &uuml;ber beide Wertebereichsgrenzen geht.
	 */
	public LinguistischeVariable lv;

	/**
	 * Testbelegung der Membervariablen erzeugen.
	 */
	public WR() {
		fsNorden = new FuzzySet("Norden", 340, 20);
		fsNordost = new FuzzySet("Nordost", 25, 65);
		fsOsten = new FuzzySet("Osten", 70, 110);
		fsSuedost = new FuzzySet("Südost", 115, 155);
		fsSueden = new FuzzySet("Süden", 160, 200);
		fsSuedwest = new FuzzySet("Südwest", 205, 245);
		fsWesten = new FuzzySet("Westen", 250, 290);
		fsNordwest = new FuzzySet("Nordwest", 295, 335);

		lv = new LinguistischeVariable("Windrichtung", 0, 360);
		lv.addFuzzySet(fsNorden);
		lv.addFuzzySet(fsNordost);
		lv.addFuzzySet(fsOsten);
		lv.addFuzzySet(fsSuedost);
		lv.addFuzzySet(fsSueden);
		lv.addFuzzySet(fsSuedwest);
		lv.addFuzzySet(fsWesten);
		lv.addFuzzySet(fsNordwest);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getAtgFuzzySets() {
		return ATG_FUZZY_SETS;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getAtgFuzzyWert() {
		return ATG_FUZZY_WERT;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public LinguistischeVariable getLinguistischeVariable() {
		return new WR().lv;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public LinguistischeVariable getLinguistischeVariable(final int szenario) {
		return new WR().lv;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getName() {
		return "WindRichtung";
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getSystemObjektTyp() {
		return "typ.ufdsWindRichtung";
	}

}
