/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.4 Funktionen Fuzzy
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.fuzzylib.fuzzylib;

import static org.junit.Assert.assertEquals;

import java.util.Map;

import org.junit.Test;

import de.bsvrz.iav.fuzzylib.QKfz;
import de.bsvrz.iav.fuzzylib.VKfz;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext;

/**
 * Testet die Klasse {@code Fuzzyfizierung}.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
@SuppressWarnings("nls")
public class TestDefuzzyfizierung {

	/**
	 * F&uuml;hrt eine kleine Massenfuzzyfizierung durch.
	 */
	@Test
	@SuppressWarnings("static-method")
	public void massendefuzzyfizierung() {
		final Defuzzyfizierung fuzzy = new Defuzzyfizierung();
		final Kontext kontext = new Kontext();
		final LinguistischeVariable vKfz2 = new VKfz(2).lv;
		final LinguistischeVariable qKfz2 = new QKfz(2).lv;
		FuzzyVariable fv;

		// Zu fuzzyfizierende Werte erfassen
		fuzzy.addFuzzyVariable("MQ1_VKfz");
		fuzzy.addFuzzyVariable("MQ1_QKfz");
		fuzzy.addFuzzyVariable("MQ2_VKfz");
		fuzzy.addFuzzyVariable("MQ2_QKfz");
		fuzzy.addFuzzyVariable("MQ3_VKfz");
		fuzzy.addFuzzyVariable("MQ3_QKfz");

		// Werte im Kontext ablegen
		fv = vKfz2.fuzzyfiziere(50);
		fv.setName("MQ1_VKfz");
		kontext.set("MQ1_VKfz", fv);

		fv = qKfz2.fuzzyfiziere(40);
		fv.setName("MQ1_QKfz");
		kontext.set("MQ1_QKfz", fv);

		fv = vKfz2.fuzzyfiziere(20);
		fv.setName("MQ2_VKfz");
		kontext.set("MQ2_VKfz", fv);

		fv = qKfz2.fuzzyfiziere(66);
		fv.setName("MQ2_QKfz");
		kontext.set("MQ2_QKfz", fv);

		fv = vKfz2.fuzzyfiziere(98);
		fv.setName("MQ3_VKfz");
		kontext.set("MQ3_VKfz", fv);

		fv = qKfz2.fuzzyfiziere(36);
		fv.setName("MQ3_QKfz");
		kontext.set("MQ3_QKfz", fv);

		// Fuzzyfizieren
		final Map<String, Integer> erg = fuzzy.interpret(kontext);

		assertEquals(6, erg.size());
		assertEquals((Integer) 57, erg.get("MQ1_VKfz"));
		assertEquals((Integer) 0, erg.get("MQ1_QKfz"));
		assertEquals((Integer) 0, erg.get("MQ2_VKfz"));
		assertEquals((Integer) 0, erg.get("MQ2_QKfz"));
		assertEquals((Integer) 254, erg.get("MQ3_VKfz"));
		assertEquals((Integer) 0, erg.get("MQ3_QKfz"));
	}

}
