/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.4 Funktionen Fuzzy
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.fuzzylib.fuzzylib;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import org.junit.Before;
import org.junit.Test;

import de.bsvrz.sys.funclib.bitctrl.interpreter.InterpreterException;

/**
 * Testet die Funktionen Klasse Term
 *
 * Beim Ausf&uuml;hren des Test ist eine nicht 100%-ige &Uuml;berdeckung des
 * Quelltext normal, da es gew&uuml;nscht ist dass einige Bedingungen (
 * {@code assert}) und Ausnahmen ({@code Exception}) entweder immer auftreten
 * oder nie auftreten.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
@SuppressWarnings("nls")
public class TestTerm {

	/**
	 * Term, der in mehreren Test verwendet wird. Er wird vor jedem Test mit
	 * identischen Werten initialisiert.
	 */
	private Term tNiedrig;

	/**
	 * Term, der in mehreren Test verwendet wird. Er wird vor jedem Test mit
	 * identischen Werten initialisiert.
	 */
	private Term tMittel;

	/**
	 * Term, der in mehreren Test verwendet wird. Er wird vor jedem Test mit
	 * identischen Werten initialisiert.
	 */
	private Term tHoch;

	/**
	 * Vor jedem Test werden die verwendeten Variablen mit einheitlichen
	 * Startwerten initialisiert.
	 */
	@Before
	public void initialisiereTest() {
		tNiedrig = new Term(null, "niedrig", 0.0f);
		tMittel = new Term(null, "mittel", 0.4f);
		tHoch = new Term(null, "hoch", 0.87f);
	}

	/**
	 * Zugeh&ouml;rigkeit setzen im erlaubten Wertebereich (0..1) und
	 * au&szlig;erhalb.
	 */
	@Test
	public void testTermAssert() {
		float f;

		for (float i = -10; i <= 20; i++) {
			f = i / 10;
			try {
				tMittel.set(f);
				assertTrue((0 <= i) && (i <= 10));
			} catch (final InterpreterException e) {
				assertTrue((i < 0) | (i > 10));
			}
		}
	}

	/**
	 * Gleichheit von Termen testen.
	 */
	@Test
	public void testTermEqual() {
		final Term termA = new Term(null, "hoch", 0.0f);
		final Term termB = new Term(null, "mittel", 0.0f);
		final Term termC = new Term(null, "hoch", 0.0f);

		// unterschiedliche Termnamen
		assertFalse(tNiedrig.equals(termA));

		// Unterschiedliche Zugehörigkeiten
		assertEquals(tMittel, termB);

		// Gleiche Termnamen und gleiche Zugehörigkeiten
		assertEquals(tHoch, termC);
	}

}
