/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.4 Funktionen Fuzzy
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.fuzzylib.fuzzylib.aggregation;

import java.util.List;

import de.bsvrz.iav.fuzzylib.fuzzylib.FuzzyVariable;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Variable;

/**
 * Ein Terminalsymbol, welches einen Fuzzy-Wert darstellt.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
public class FuzzySymbol implements Variable {

	/**
	 * Der Name der Variable im Kontext.
	 */
	private final String name;

	/**
	 * Konstruiert ein Terminalsymbol mit dem angegebenen Namen.
	 *
	 * @param name
	 *            Name der Variable im Kontext
	 * @throws de.bsvrz.sys.funclib.bitctrl.interpreter.InterpreterException
	 *             Wenn der Name der Fuzzy-Variable oder des Terms {@code null}
	 *             ist oder nur aus Leerzeichen besteht
	 */
	public FuzzySymbol(final String name) {
		Kontext.pruefeName(name);
		this.name = name.trim();
	}

	/**
	 * Gibt immer {@code null} zur&uuml;ck, da dies ein Terminalsymbol ist.
	 * <p>
	 * {@inheritDoc}
	 */
	@Override
	public List<Ausdruck> getNachfolger() {
		return null;
	}

	/**
	 * Nennt den Namen des Terminalsymbols.
	 *
	 * @return Variablenname
	 */
	@Override
	public String getName() {
		assert(name != null) && (name != ""); //$NON-NLS-1$

		return name;
	}

	/**
	 * Gibt die Fuzzy-Variable zur&uuml;ck, den dieses Symbol darstellt.
	 *
	 * {@inheritDoc}
	 */
	@Override
	public Object interpret(final Kontext kontext) {
		return kontext.get(getName(), FuzzyVariable.class);
	}

	/**
	 * Gibt den Namen des Symbols zur&uuml;ck.
	 *
	 * {@inheritDoc}
	 *
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return getName();
	}

}
